summaryrefslogtreecommitdiff
path: root/src/third_party/wiredtiger/test/cppsuite/test_harness/workload_generator.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/third_party/wiredtiger/test/cppsuite/test_harness/workload_generator.h')
-rw-r--r--src/third_party/wiredtiger/test/cppsuite/test_harness/workload_generator.h8
1 files changed, 3 insertions, 5 deletions
diff --git a/src/third_party/wiredtiger/test/cppsuite/test_harness/workload_generator.h b/src/third_party/wiredtiger/test/cppsuite/test_harness/workload_generator.h
index 0b6cc1b2a84..23fbc25ddf9 100644
--- a/src/third_party/wiredtiger/test/cppsuite/test_harness/workload_generator.h
+++ b/src/third_party/wiredtiger/test/cppsuite/test_harness/workload_generator.h
@@ -54,8 +54,9 @@ class workload_generator : public component {
delete it;
}
/* Delete the copy constructor. */
workload_generator(const workload_generator &) = delete;
+ workload_generator &operator=(const workload_generator &) = delete;
/*
* Function that performs the following steps using the configuration that is defined by the
@@ -129,7 +130,6 @@ class workload_generator : public component {
void
run()
{
- WT_SESSION *session = nullptr;
int64_t duration_seconds, read_threads, min_operation_per_transaction,
max_operation_per_transaction, value_size;
@@ -204,7 +204,6 @@ class workload_generator : public component {
update_operation(thread_context &context, WT_SESSION *session)
{
WT_CURSOR *cursor;
- WT_DECL_RET;
wt_timestamp_t ts;
std::vector<WT_CURSOR *> cursors;
std::vector<std::string> collection_names;
@@ -246,7 +245,6 @@ class workload_generator : public component {
read_operation(thread_context &context, WT_SESSION *session)
{
WT_CURSOR *cursor;
- WT_DECL_RET;
std::vector<WT_CURSOR *> cursors;
testutil_assert(session != nullptr);
@@ -259,7 +257,7 @@ class workload_generator : public component {
while (context.is_running()) {
/* Walk each cursor. */
for (const auto &it : cursors) {
- if ((ret = it->next(it)) != 0)
+ if (it->next(it) != 0)
it->reset(it);
}
}
@@ -54,8 +54,9 @@ class workload_generator : public component {
delete it;
}
- /* Delete the copy constructor. */
+ /* Delete the copy constructor and the assignment operator. */
workload_generator(const workload_generator &) = delete;